@@ -245,8 +245,16 @@ class ProjectTree(QtWidgets.QTreeWidget):
 	### Public functions
 
 	def set_filter(self, filetypes):
-		""" Sets the filter parameters.
-		Can be used instead of using project_tree.filter = <value> directly.
+		""" Sets an extension based filter for items in the tree.
+
+		.. note :: Can be used instead of using ProjectTree.filter = <value> directly.
+		
+		Parameters
+		----------
+		filetypes : str or list
+			A filetype or list of filetypes that should be shown while other file
+			types are hidden. For example, passing '.txt' to this function will
+			only show files which have the .txt extension
 		"""
 		self.filter = filetypes
 
@@ -521,9 +529,9 @@ class ProjectTree(QtWidgets.QTreeWidget):
 				item, kind = self.add_item(parent, entry)
 			except RuntimeError as e:
 				# If a runtime error occured the tree was probably reset or 
-				# another event  deleted treeWidgetItems. Not much that can be
+				# another event deleted treeWidgetItems. Not much that can be
 				# done here, so do some cleanup and quit
-				warnings.warn(e)
+				warnings.warn(str(e))
 				self.__cleanup_reply(reply)
 				return
 
